Learn R Programming

metainc (version 0.2-1)

anticoagulation: Sampled odds ratios from meta-analysis on the association between parenteral anticoagulation and mortality in patients with cancer

Description

Matrix with sampled odds ratios from meta-analysis on the association between parenteral anticoagulation and mortality in patients with cancer (Akl et al., 2017).

Arguments

Format

A matrix with 5000 sampled odds ratios (rows) for 18 studies (columns) following a Bayesian meta-analysis.

Details

Data from Akl et al. (2017) and displaying results presented as odds ratios. Each column corresponds to a different primary study.

See Also

inc, anticoagulation_df

Examples

Run this code

data(anticoagulation)

# Since the results are already presented as odds ratios, we need
# to indicate that effects have not been transformed to log odds
# ratios yet (\code{transf = FALSE}).
dis1 <- inc(anticoagulation, br = 0.504, dt1 = 16, sm = "OR",
  transf = FALSE)
dis1

# Alternatively, we may simply apply the \code{inc()} function to
# log odds ratios.
data(anticoagulation)
dis2 <- inc(log(anticoagulation), br = 0.504, dt1 = 16, sm = "OR")
dis2

Run the code above in your browser using DataLab