Learn R Programming

metainc (version 0.2-1)

anticoagulation_df: Meta-analysis on the association between parenteral anticoagulation and mortality in patients with cancer

Description

Data set from meta-analysis on the association between parenteral anticoagulation and mortality in patients with cancer (Akl et al., 2017). For each primary study, results are expressed as a log odds ratio.

Arguments

Details

Data frame containing, for each primary study of the meta-analysis from Akl et al. (2017):

  1. number of events (variables rA and rB) and total number of participants (nA and nB) for each group,

  2. effect sizes [ln OR] (yi),

  3. respective variances (vi),

  4. risk of bias assessment (RoB).

See Also

inc, anticoagulation

Examples

Run this code

data(anticoagulation_df)
m1 <- meta::metagen(yi, sqrt(vi), sm = "OR", data = anticoagulation_df,
  studlab = LETTERS[1:18])
set.seed(1090) # Make sampled effect sizes reproducible
sample1 <- getsamples(m1)
dis1 <- inc(sample1, dt1 = 16, dt2 = 31, dt3 = 60, br = 0.504, sm = "OR")
dis1

if(requireNamespace("metafor")){
# Same sampled effect sizes using R package 'metafor' (must be installed)
m2 <- metafor::rma(anticoagulation_df, measure = "OR", slab = LETTERS[1:18])
set.seed(1090) # Make sampled effect sizes reproducible
sample2 <- getsamples(m2)
dis2 <- inc(sample2, dt1 = 16, dt2 = 31, dt3 = 60, br = 0.504, sm = "OR")
dis2

all.equal(sample1, sample2) # Only difference: package name
}

Run the code above in your browser using DataLab