Learn R Programming

metainc (version 0.2-1)

or2rr: Calculate risk ratios from odds ratios and baseline risk

Description

Calculate risk ratios from odds ratios and baseline risk.

Usage

or2rr(or, br)

Value

A vector or matrix with risk ratios.

Arguments

or

Odds ratio(s).

br

Baseline risk (also known as assumed comparator risk), i.e., risk that the outcome of interest would occur in the comparator intervention. It must be expressed as a value between 0 and 1.

Author

Bernardo Sousa-Pinto bernardo@med.up.pt, Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de

Details

Converts odds ratios (OR) into risk ratios (RR) using the formula available in Schunemann et al. (2019), Chapter 15:

RR = OR / (1 - br x (1 - OR)),

with br corresponding to the baseline risk (the assumed comparator risk; i.e., the risk that the outcome of interest would occur in the comparison intervention).

References

Schunemann HJ, Vist GE, Higgins JPT, et al. (2019). “Interpreting results and drawing conclusions.” Cochrane Handbook for Systematic Reviews of Interventions, 403--431.

Examples

Run this code
data(anticoagulation)
RRs <- or2rr(anticoagulation, br = 0.5)
head(RRs)

Run the code above in your browser using DataLab