Sensitivity analysis on the Decision Inconsistency index and the Across-Studies Inconsistency index based on a range of baseline risks. It is applicable only to meta-analyses with a binary outcome (effect size measures expressed as risk ratios, odds ratios or hazard ratios).
sens_br(x, br1, br2, dt1, dt2 = NULL, dt3 = NULL, sm, by = 0.01, scale = 1000)# S3 method for sens_br
plot(
x,
ylim1 = c(0, 100),
ylim2 = c(0, 100),
ylab1 = "DI index (%)",
ylab2 = "ASI index (%)",
...
)
A data frame containing
Baseline risk
Decision Inconsistency index at baseline risk
Across-Studies Inconsistency index at baseline risk
An R object created with getsamples or a matrix
containing sampled effect sizes of primary studies. Note, log
transformed effect sizes must be provided (e.g., log odds ratios
instead of odds ratios).
Smallest baseline risk considered.
Largest baseline risk considered.
A single numeric defining the decision threshold to
distinguish (i) meaningful from trivial effects, if arguments
dt2 and dt3 are not provided, or (ii) small from
trivial effects if arguments dt2 and dt3 are
provided.
A single numeric defining the decision threshold to distinguish moderate from small effects provided.
A single numeric defining the decision threshold to distinguish large from moderate effects.
A character string indicating the summary measure used in
primary studies (either sm = "OR", sm = "RR" or
sm = "HR").
Increment of the sequence from br1 to br2.
The number of people per which absolute decision thresholds are provided (default: 1000, i.e., absolute decision threshold values are defined per 1000 people).
The y limits (min, max) of the plot showing the Decision Inconsistency index.
The y limits (min, max) of the plot showing the Across-Studies Inconsistency index.
A label for the y-axis (Decision Inconsistency index).
A label for the y-axis (Across-Studies Inconsistency index).
Additional graphical arguments (ignored).
Bernardo Sousa-Pinto bernardo@med.up.pt, Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de
Computes the Decision Inconsistency index (DI) and the
Across-Studies Inconsistency index (ASI) across a range of baseline risks.
It can only be applied for meta-analyses with binary outcome data (effect
size measures expressed as (log) risk ratios, odds ratios or hazard ratios),
with the DI and the ASI being calculated based on absolute effects.
As a result, the decision threshold values (dt1, dt2,
dt3) must be provided as absolute effects. By default, it is assumed
that threshold values are provided as numbers of events per 1000
persons (scale = 1000).
Schunemann HJ, Higgins JPT, Vist GE, et al. (2019). “Completing ‘Summary of findings’ tables and grading the certainty of the evidence.” Cochrane Handbook for Systematic Reviews of Interventions, 375--402.
Skoetz N, Goldkuhle M, van Dalen EC, et al. (2020). “GRADE guidelines 27: how to calculate absolute effects for time-to-event outcomes in summary of findings tables and Evidence Profiles.” Journal of Clinical Epidemiology, 118, 124--131.
Sousa-Pinto B, Neumann I, Vieira RJ, et al. (2025). “Quantitative assessment of inconsistency in meta-analysis using decision thresholds with two new indices.” Journal of Clinical Epidemiology, 181, 111725.
# \donttest{
data(anticoagulation)
dis <- sens_br(log(anticoagulation), br1 = 0.3, br2 = 0.7, dt1 = 20,
sm = "OR", by = 0.1)
dis
plot(dis, ylim1 = c(0, 100), ylim2 = c(0, 50))
# }
Run the code above in your browser using DataLab