Sensitivity analysis on the Decision Inconsistency index and the Across-Studies Inconsistency index based on a range of decision thresholds distinguishing meaningful versus trivial effects. It is applicable only to meta-analyses with binary outcome data (effect size measures expressed as risk ratios, odds ratios or hazard ratios).
sens_dt(x, br = NULL, min1, max1, min2, max2, sm, by = 1, scale = 1000)heatplot(x, limits1 = NULL, limits2 = NULL, ...)
A data frame containing
Lower decision threshold
Higher decision threshold
Decision Inconsistency index for each combination of decision thresholds
Across-Studies Inconsistency index for each combination of decision thresholds
An R object created with getsamples or a matrix
containing the samples of the effect sizes of primary
studies. Note that log-transformed effect sizes must be provided
(e.g., log odds ratios instead of odds ratios).
Baseline risk.
A single numeric defining the lowest value for the
lower decision threshold. Must be lower than max1,
min2 and max2.
A single numeric defining the highest value for the
lower decision threshold. Must be higher than min1, but
lower than min2 and max2.
A single numeric defining the lowest value for the
higher decision threshold. Must be higher than min1 and
max1, but lower than max2.
A single numeric defining the highest value for the
higher decision threshold. Must be higher than min1,
max1 and min2.
A character string indicating the summary measure used in
primary studies (either sm = "OR", sm = "RR" or
sm = "HR").
Increment of the sequences from min1 to
max1 and min2 to max2.
The number of people per which absolute decision thresholds are provided (default: 1000, i.e., absolute decision threshold values are defined per 1000 people).
Limits for the colour range in the heatplot showing the Decision Inconsistency index.
Limits for the colour range in the heatplot showing the Across-Studies Inconsistency index.
Additional graphical arguments (ignored).
Bernardo Sousa-Pinto bernardo@med.up.pt, Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de
Computes the Decision Inconsistency index
(DI) and the Across-Studies Inconsistency index (ASI) across a range of
decision thresholds distinguishing meaningful vs trivial effects. This
function can only be applied to dichotomous outcomes expressed as (log-) odds
ratio, risk ratio and hazard ratio.
Graphical representations can be obtained using the heatplot function.
Schunemann HJ, Higgins JPT, Vist GE, et al. (2019). “Completing ‘Summary of findings’ tables and grading the certainty of the evidence.” Cochrane Handbook for Systematic Reviews of Interventions, 375--402.
Skoetz N, Goldkuhle M, van Dalen EC, et al. (2020). “GRADE guidelines 27: how to calculate absolute effects for time-to-event outcomes in summary of findings tables and Evidence Profiles.” Journal of Clinical Epidemiology, 118, 124--131.
Sousa-Pinto B, Neumann I, Vieira RJ, et al. (2025). “Quantitative assessment of inconsistency in meta-analysis using decision thresholds with two new indices.” Journal of Clinical Epidemiology, 181, 111725.
# \donttest{
data(anticoagulation)
dis <- sens_dt(log(anticoagulation),
br = 0.5, min1 = -20, max1 = -10, min2 = 10, max2 = 20, sm = "or")
#
head(dis)
summary(dis$DI)
summary(dis$ASI)
heatplot(dis)
# }
Run the code above in your browser using DataLab