data(anticoagulation)
# Since the results are already presented as odds ratios, we need
# to indicate that effects have not been transformed to log odds
# ratios yet (\code{transf = FALSE}).
dis1 <- inc(anticoagulation, br = 0.504, dt1 = 16, sm = "OR",
transf = FALSE)
dis1
# Alternatively, we may simply apply the \code{inc()} function to
# log odds ratios.
data(anticoagulation)
dis2 <- inc(log(anticoagulation), br = 0.504, dt1 = 16, sm = "OR")
dis2
Run the code above in your browser using DataLab